@@ -5,12 +5,11 @@ import tarfile
 import json
 from collections import namedtuple
 from itertools import chain
-from datetime import datetime
 
 from metaflow.metaflow_environment import MetaflowEnvironment
 from metaflow.exception import MetaflowNotFound,\
-    MetaflowNamespaceMismatch,\
-    MetaflowInternalError
+                               MetaflowNamespaceMismatch,\
+                               MetaflowInternalError
 
 from metaflow.metaflow_config import DEFAULT_METADATA
 from metaflow.plugins import ENVIRONMENTS, METADATA_PROVIDERS
@@ -66,8 +65,7 @@ def metadata(ms):
     infos = ms.split('@', 1)
     types = [m.TYPE for m in METADATA_PROVIDERS]
     if infos[0] in types:
-        current_metadata = [
-            m for m in METADATA_PROVIDERS if m.TYPE == infos[0]][0]
+        current_metadata = [m for m in METADATA_PROVIDERS if m.TYPE == infos[0]][0]
         if len(infos) > 1:
             current_metadata.INFO = infos[1]
     else:
@@ -347,19 +345,18 @@ class MetaflowObject(object):
             raise MetaflowInternalError(msg="Unknown type: %s" % self._NAME)
 
         self._created_at = time.strftime(
-            '%Y-%m-%dT%H:%M:%SZ', time.gmtime(self._object['ts_epoch']))
+            '%Y-%m-%dT%H:%M:%SZ', time.gmtime(self._object['ts_epoch']//1000))
 
         self._tags = frozenset(chain(self._object.get('system_tags') or [],
                                      self._object.get('tags') or []))
 
         self._aero_user = self._object.get("user_name", None)
-
+        
         if _namespace_check and not self.is_in_namespace():
             raise MetaflowNamespaceMismatch(current_namespace)
 
     def _get_object(self, *path_components):
-        result = self._metaflow.metadata.get_object(
-            self._NAME, 'self', None, *path_components)
+        result = self._metaflow.metadata.get_object(self._NAME, 'self', None, *path_components)
 
         if not result:
             raise MetaflowNotFound("%s does not exist" % self)
@@ -380,10 +377,9 @@ class MetaflowObject(object):
             flow_id = self._object.get('flow_id').lower()
         else:
             flow_id = self._path_components[0].lower()
-
+        
         if current_namespace == "production":
-            query_filter = {
-                'any_tags': f"production:{self._aero_user}_{flow_id}"}
+            query_filter = {'any_tags': f"production:{self._aero_user}_{flow_id}"}
         else:
             query_filter = {'any_tags': f"user:{self._aero_user}"}
 
@@ -426,7 +422,7 @@ class MetaflowObject(object):
 
         if self._NAME == 'flow':
             return any(True for _ in self)
-
+        
         return True
 
     def __str__(self):
@@ -533,8 +529,7 @@ class MetaflowObject(object):
             # We can skip the namespace check because if self._NAME = 'run',
             # the parent object is guaranteed to be in namespace.
             # Otherwise the check is moot for Flow since parent is singular.
-            self._parent = _CLASSES[self._PARENT_CLASS](
-                parent_pathspec, _namespace_check=False)
+            self._parent = _CLASSES[self._PARENT_CLASS](parent_pathspec, _namespace_check=False)
         return self._parent
 
     @property
@@ -1064,8 +1059,7 @@ class Task(MetaflowObject):
         env_type = my_code.info['environment_type']
         if not env_type:
             return None
-        env = [m for m in ENVIRONMENTS +
-               [MetaflowEnvironment] if m.TYPE == env_type][0]
+        env = [m for m in ENVIRONMENTS + [MetaflowEnvironment] if m.TYPE == env_type][0]
         return env.get_client_info(self.path_components[0], self.metadata_dict)
 
     def _load_log(self, stream):
