@@ -1,7 +1,5 @@
 # File modified under the Apache Licence 2.0 spec. Modified by Aero Technologies.
 # Altered how profile is set based on local/remote execution
-from aws_requests_auth.boto_utils import get_credentials
-from aws_requests_auth.aws_auth import AWSRequestsAuth
 import logging
 import os
 import urllib.parse
@@ -120,12 +118,14 @@ def get_aws_client(module, with_error=False, params={}):
     return AWS_SESSION.client(module, **params)
 
 
+from aws_requests_auth.aws_auth import AWSRequestsAuth
+from aws_requests_auth.boto_utils import get_credentials
+
 class AeroAWSRequestsAuth(AWSRequestsAuth):
 
     def __init__(self, aws_host, aws_region, aws_service, session):
 
-        super(AeroAWSRequestsAuth, self).__init__(
-            None, None, aws_host, aws_region, aws_service)
+        super(AeroAWSRequestsAuth, self).__init__(None, None, aws_host, aws_region, aws_service)
         self._refreshable_credentials = session.get_credentials()
 
     def get_aws_request_headers_handler(self, r):
@@ -134,42 +134,42 @@ class AeroAWSRequestsAuth(AWSRequestsAuth):
         credentials = get_credentials(self._refreshable_credentials)
         return self.get_aws_request_headers(r, **credentials)
 
-
 def get_auth_object(
     url: str,
-    region: str = 'eu-west-1',
+    region: str = 'eu-west-1', 
     service: str = 'execute-api'
 ):
     split_url = url.split("/")
-    endpoint = split_url[2]  # Just the domain
+    endpoint = split_url[2] # Just the domain
     return AeroAWSRequestsAuth(
         endpoint, region, service, AWS_SESSION
     )
 
-
 def get_signed_url(
-    url: str,
-    method: str,
-    dt: datetime = None,
-    region: str = 'eu-west-1',
-    service: str = 'execute-api',
-    protocol: str = 'https://',
-    query_string_params: str = None,
-    payload: str = ""
-):
+        url: str,
+        method: str,
+        dt: datetime = None,
+        region: str = 'eu-west-1', 
+        service: str = 'execute-api', 
+        protocol: str = 'https://', 
+        query_string_params: str = None,
+        payload: str = ""
+    ):
 
     credentials = _get_base_session_credentials()
     # eg: "https://api.aeroplatform.co.uk/service-api/flows/DailyScheduleTest2/runs/15/steps/end/tasks"
 
     split_url = url.split("/")
-    endpoint = split_url[2]  # Just the domain
-    path = "/".join(split_url[3:])  # All the rest
+    endpoint = split_url[2] # Just the domain
+    path = "/".join(split_url[3:]) # All the rest
+
 
     if not dt:
         dt = datetime.utcnow()
     now = dt.strftime("%Y%m%dT%H%M%SZ")
     today = dt.strftime("%Y%m%d")
 
+
     algorithm = 'AWS4-HMAC-SHA256'
     credential_scope = today + '/' + region + \
         '/' + service + '/' + 'aws4_request'
