@@ -15,7 +15,7 @@ from metaflow.package import MetaflowPackage
 from metaflow.plugins import BatchDecorator
 from metaflow.util import get_username, to_bytes, to_unicode
 
-from .step_functions import StepFunctions
+from .step_functions import StepFunctions, StepFunctionsException
 from .production_token import load_token, store_token, new_token
 
 VALID_NAME = re.compile('[^a-zA-Z0-9_\-\.]')
@@ -428,12 +428,12 @@ def get_logs(obj, flow_id=None):
     cloudwatch = get_aws_client('logs')
 
     cli_state = {
-        "flow_id": obj.flow.name
+        "flow_id": obj.state_machine_name
     }
 
     # Execution (Run) > Step > Task
     question_arr = [
-        ask_execution_question, 
+        ask_execution_question,
         ask_step_question, 
         ask_task_question
     ]
@@ -624,6 +624,10 @@ def ask_execution_question(obj, cloudwatch=None, sfn=None):
 
     flow_state_machine = get_key(functions, "name", obj['flow_id'])
 
+    if flow_state_machine is None:
+        raise StepFunctionsException("The workflow *%s* doesn't exist "
+                                     "on Aero scheduler." % obj['flow_id'])
+
     executions = sfn.list_executions(
         stateMachineArn=flow_state_machine['stateMachineArn']
     )['executions']
